unit Errors;

(*
   NXP library use error codes:
   0x01 - 0x0C
   0x20-0x26
   0x71, 0x072, 0x7F
   We use additional codes from 0x80
*)

                            interface
////////////////////////////////////////////////////////////////////////////////
const

  ERR_RESULT_OK         = $00;

  // ERRORS from NXP library
  PH_ERR_IO_TIMEOUT               = $01; //**< No reply received, e.g. PICC removal. */
  PH_ERR_INTEGRITY_ERROR          = $02; //**< Wrong CRC or parity detected. */
  PH_ERR_COLLISION_ERROR          = $03; //**< A collision occured. */
  PH_ERR_BUFFER_OVERFLOW          = $04; //**< Attempt to write beyond buffer size. */
  PH_ERR_FRAMING_ERROR            = $05; //**< Invalid frame format. */
  PH_ERR_PROTOCOL_ERROR           = $06; //**< Received response violates protocol. */
  PH_ERR_AUTH_ERROR               = $07; //**< Authentication error. */
  PH_ERR_READ_WRITE_ERROR         = $08; //**< A Read or Write error occured in RAM/ROM or Flash. */
  PH_ERR_TEMPERATURE_ERROR        = $09; //**< The RC sensors signal overheating. */
  PH_ERR_RF_ERROR                 = $0A; //**< Error on RF-Interface. */
  PH_ERR_INTERFACE_ERROR          = $0B; //**< An error occured in RC communication. */
  PH_ERR_LENGTH_ERROR             = $0C; //**< A length error occured. */
  PH_ERR_INTERNAL_ERROR           = $7F; //**< An internal error occured. */
  //
  PH_ERR_INVALID_DATA_PARAMS      = $20; //**< Invalid data parameters supplied (layer id check failed). */
  PH_ERR_INVALID_PARAMETER        = $21; //**< Invalid parameter supplied. */
  PH_ERR_PARAMETER_OVERFLOW       = $22; //**< Reading/Writing a parameter would produce an overflow. */
  PH_ERR_UNSUPPORTED_PARAMETER    = $23; //**< Parameter not supported. */
  PH_ERR_UNSUPPORTED_COMMAND      = $24; //**< Command not supported. */
  PH_ERR_USE_CONDITION            = $25; //**< Condition of use not satisfied. */
  PH_ERR_KEY                      = $26; //**< A key error occured. */
  //
  PH_ERR_SUCCESS_CHAINING         = $71; //**< Rx chaining is not complete, further action needed. */
  PH_ERR_SUCCESS_INCOMPLETE_BYTE  = $72; //**< An incomplete byte was received. */

  // In the library PH_ERR_CUSTOM_BEGIN = 0x80
  // and uses about 10 codes - so, we start from 0xA0
  PH_ERR_CUSTOM_BEGIN             = $80;
  // For Mifare defined codes
  PHPAL_MIFARE_ERR_NAK0           = (PH_ERR_CUSTOM_BEGIN+0);
  PHPAL_MIFARE_ERR_NAK1           = (PH_ERR_CUSTOM_BEGIN+1);
  PHPAL_MIFARE_ERR_NAK4           = (PH_ERR_CUSTOM_BEGIN+2);
  PHPAL_MIFARE_ERR_NAK5           = (PH_ERR_CUSTOM_BEGIN+3);
  PHPAL_MIFARE_ERR_NAK6           = (PH_ERR_CUSTOM_BEGIN+4);
  PHPAL_MIFARE_ERR_NAK7           = (PH_ERR_CUSTOM_BEGIN+5);
  PHPAL_MIFARE_ERR_NAK8           = (PH_ERR_CUSTOM_BEGIN+6);
  PHPAL_MIFARE_ERR_NAK9           = (PH_ERR_CUSTOM_BEGIN+7);
  // For Mifare Plus defined codes
  PHAL_MFP_ERR_AUTH               = (PH_ERR_CUSTOM_BEGIN+0); //     /*< MFP Authentication Error. */
  PHAL_MFP_ERR_CMD_OVERFLOW       = (PH_ERR_CUSTOM_BEGIN+1); //     /*< MFP Command Overflow Error. */
  PHAL_MFP_ERR_MAC_PCD            = (PH_ERR_CUSTOM_BEGIN+2); //     /*< MFP MAC Error. */
  PHAL_MFP_ERR_BNR                = (PH_ERR_CUSTOM_BEGIN+3); //     /*< MFP Blocknumber Error. */
  PHAL_MFP_ERR_EXT                = (PH_ERR_CUSTOM_BEGIN+4); //     /*< MFP Extension Error. */
  PHAL_MFP_ERR_CMD_INVALID        = (PH_ERR_CUSTOM_BEGIN+5); //     /*< MFP Invalid Command Error. */
  PHAL_MFP_ERR_FORMAT             = (PH_ERR_CUSTOM_BEGIN+6); //     /*< MFP Authentication Error. */
  PHAL_MFP_ERR_GEN_FAILURE        = (PH_ERR_CUSTOM_BEGIN+7); //     /*< MFP Generic Error. */

  // Internal server errors
  ERR_COMM_TIMEOUT      = $A0;
  ERR_BAD_PACKET_CRC    = $A1;
  ERR_OPEN_PORT         = $A2;
  ERR_WRONG_COMPORT     = $A3;
  ERR_COM_CLOSED        = $A4;
  ERR_COM_WRITEERR      = $A5;
  ERR_INVALID_HANDLE    = $A6;
  ERR_RESULT_EMPTY      = $A7;

  // error code answers from reader
  ERR_INVALID_DATA      = $A8;
  ERR_INVALID_COMMAND   = $A9;
  ERR_INVALID_PARAM     = $AA;


                            implementation
////////////////////////////////////////////////////////////////////////////////
///
end.
